@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -192,8 +192,8 @@ dircmp_rcs(struct dircmp_args *dca)
 					list_destroy(lp);
 					return (false);
 				}
-				memcpy(&dca->dca_path[dca->dca_pathlen],
-				       mdp->md_name, mdp->md_namelen);
+				(void)memcpy(&dca->dca_path[dca->dca_pathlen],
+					     mdp->md_name, mdp->md_namelen);
 				dca->dca_path[len - 1] = '/';
 				dca->dca_path[len] = '\0';
 
@@ -403,11 +403,13 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	list_set_destructor(lp, mclosedir);
 
 	len = dca->dca_pathlen + mdp->md_namelen + 1;
-	if (len >= dca->dca_pathmax)
+	if (len >= dca->dca_pathmax) {
+		list_destroy(lp);
 		return (false);
+	}
 
-	memcpy(&dca->dca_path[dca->dca_pathlen], mdp->md_name,
-	       mdp->md_namelen);
+	(void)memcpy(&dca->dca_path[dca->dca_pathlen], mdp->md_name,
+		     mdp->md_namelen);
 	dca->dca_path[len - 1] = '/';
 	dca->dca_path[len] = '\0';
 
@@ -450,8 +452,8 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 					list_destroy(lp);
 					return (false);
 				}
-				memcpy(&dca->dca_path[dca->dca_pathlen],
-				       mdp->md_name, mdp->md_namelen);
+				(void)memcpy(&dca->dca_path[dca->dca_pathlen],
+					     mdp->md_name, mdp->md_namelen);
 				dca->dca_path[len - 1] = '/';
 				dca->dca_path[len] = '\0';
 
@@ -615,8 +617,8 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 		return (false);
 	}
 
-	memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
-	       cap->ca_namelen);
+	(void)memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
+		     cap->ca_namelen);
 	dca->dca_path[len - 1] = '/';
 	dca->dca_path[len] = '\0';
 	dca->dca_pathlen = len;
@@ -640,9 +642,10 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 					free(plen_stack);
 					return (false);
 				}
-				memcpy(newp, plen_stack, old * sizeof(*newp));
-				memset(&newp[old], 0,
-				       (new - old) * sizeof(*newp));
+				(void)memcpy(newp, plen_stack,
+					     old * sizeof(*newp));
+				(void)memset(&newp[old], 0,
+					     (new - old) * sizeof(*newp));
 
 				free(plen_stack);
 				plen_stack = newp;
@@ -656,8 +659,8 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 				return (false);
 			}
 
-			memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
-			       cap->ca_namelen);
+			(void)memcpy(&dca->dca_path[dca->dca_pathlen],
+				     cap->ca_name, cap->ca_namelen);
 			dca->dca_path[len - 1] = '/';
 			dca->dca_path[len] = '\0';
 			dca->dca_pathlen = len;
@@ -685,6 +688,7 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 			}
 			break;
 		default:
+			free(plen_stack);
 			return (false);
 		}
 	} while (c > 0);
@@ -850,8 +854,8 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	case S_IFLNK:
 		if (cap->ca_type != FILETYPE_SYMLINK)
 			return (dircmp_rcs_replace(dca, mdp));
-		memcpy(&dca->dca_path[dca->dca_pathlen], mdp->md_name,
-		       mdp->md_namelen);
+		(void)memcpy(&dca->dca_path[dca->dca_pathlen], mdp->md_name,
+			     mdp->md_namelen);
 		dca->dca_path[dca->dca_pathlen + mdp->md_namelen] = '\0';
 		if ((wn = readlink(dca->dca_path, dca->dca_symlink,
 				   dca->dca_pathmax)) == -1) {
@@ -922,7 +926,7 @@ dircmp_rcs_opendir(struct dircmp_args *dca, size_t pathlen)
 		free(mdp);
 		return (NULL);
 	}
-	memcpy(mdp->md_name, &cl->cl_rprefix[rpathlen], len);
+	(void)memcpy(mdp->md_name, &cl->cl_rprefix[rpathlen], len);
 	mdp->md_namelen = len;
 	mdp->md_attic = false;
 	mdp->md_dead = false;
@@ -932,8 +936,8 @@ dircmp_rcs_opendir(struct dircmp_args *dca, size_t pathlen)
 		free(mdp);
 		return (NULL);
 	}
-	memcpy(&dca->dca_path[cl->cl_prefixlen], cl->cl_rprefix,
-	       rpathlen + mdp->md_namelen);
+	(void)memcpy(&dca->dca_path[cl->cl_prefixlen], cl->cl_rprefix,
+		     rpathlen + mdp->md_namelen);
 	dca->dca_path[len] = '\0';
 
 	if (cl->cl_symfollow)
