@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -511,7 +511,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 		dca->dca_pathlen = attr->a_namelen + 1;
 		if (dca->dca_pathlen >= dca->dca_pathmax)
 			return (false);
-		memcpy(dca->dca_path, attr->a_name, attr->a_namelen);
+		(void)memcpy(dca->dca_path, attr->a_name, attr->a_namelen);
 		dca->dca_path[attr->a_namelen] = '/';
 	} else {
 		dca->dca_pathlen = 0;
@@ -526,11 +526,16 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 	plen_stack[0] = dca->dca_pathlen;
 	c = 1;
 
-	if ((len =  dca->dca_pathlen + cap->ca_namelen + 1) >= dca->dca_pathmax)
+	len =  dca->dca_pathlen + cap->ca_namelen + 1;
+	if (len >= dca->dca_pathmax) {
+		free(plen_stack);
 		return (false);
-	memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
-	       cap->ca_namelen);
-	dca->dca_path[dca->dca_pathlen + cap->ca_namelen] = '/';
+	}
+
+	(void)memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
+		     cap->ca_namelen);
+	dca->dca_path[len - 1] = '/';
+	dca->dca_path[len] = '\0';
 	dca->dca_pathlen = len;
 
 	do {
@@ -552,9 +557,10 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 					free(plen_stack);
 					return (false);
 				}
-				memcpy(newp, plen_stack, old * sizeof(*newp));
-				memset(&newp[old], 0,
-				       (new - old) * sizeof(*newp));
+				(void)memcpy(newp, plen_stack,
+					     old * sizeof(*newp));
+				(void)memset(&newp[old], 0,
+					     (new - old) * sizeof(*newp));
 
 				free(plen_stack);
 				plen_stack = newp;
@@ -568,19 +574,23 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 				return (false);
 			}
 
-			memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
-			       cap->ca_namelen);
+			(void)memcpy(&dca->dca_path[dca->dca_pathlen],
+				     cap->ca_name, cap->ca_namelen);
 			dca->dca_path[len - 1] = '/';
+			dca->dca_path[len] = '\0';
 			dca->dca_pathlen = len;
 
 			break;
 		case DIRCMP_UP:
+			dca->dca_path[dca->dca_pathlen - 1] = '\0';
+
 			if (!dircmp_rcs_scanfile_remove_dir(dca)) {
 				free(plen_stack);
 				return (false);
 			}
 
 			dca->dca_pathlen = plen_stack[--c];
+			dca->dca_path[dca->dca_pathlen] = '\0';
 
 			break;
 		case DIRCMP_FILE:
@@ -593,6 +603,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 			}
 			break;
 		default:
+			free(plen_stack);
 			return (false);
 		}
 	} while (c > 0);
