@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -289,7 +289,7 @@ filecmp_rcs_fetch(struct filecmp_args *fca)
 	if ((pathlen = fca->fca_pathlen + cap->ca_namelen) >= fca->fca_pathmax)
 		return (false);
 
-	memcpy(fca->fca_rpath, cap->ca_name, cap->ca_namelen);
+	(void)memcpy(fca->fca_rpath, cap->ca_name, cap->ca_namelen);
 	fca->fca_rpath[cap->ca_namelen] = '\0';
 	if (cap->ca_type == FILETYPE_RCS_ATTIC) {
 		if (!cvsync_rcs_insert_attic(fca->fca_path, pathlen,
@@ -2491,7 +2491,7 @@ filecmp_rcs_ignore_rcs_list(struct filecmp_args *fca, uint8_t type)
 
 	if (!mux_recv(fca->fca_mux, MUX_FILECMP_IN, cmd, 2))
 		return (false);
-	if (GetWord(cmd) != len)
+	if (GetWord(cmd) != (uint16_t)len)
 		return (false);
 	if (!mux_recv(fca->fca_mux, MUX_FILECMP_IN, cmd, len))
 		return (false);
