@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -268,7 +268,7 @@ filescan_rcs_fetch(struct filescan_args *fsa)
 	if ((pathlen = fsa->fsa_pathlen + cap->ca_namelen) >= fsa->fsa_pathmax)
 		return (false);
 
-	memcpy(fsa->fsa_rpath, cap->ca_name, cap->ca_namelen);
+	(void)memcpy(fsa->fsa_rpath, cap->ca_name, cap->ca_namelen);
 	fsa->fsa_rpath[cap->ca_namelen] = '\0';
 	if (cap->ca_type == FILETYPE_RCS_ATTIC) {
 		if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
@@ -375,7 +375,7 @@ filescan_rcs_attic(struct filescan_args *fsa)
 			return (false);
 		return (filescan_rcs_add(fsa));
 	}
-	if (!cvsync_mmap(cfp, 0, cfp->cf_size)) {
+	if (!cvsync_mmap(cfp, (off_t)0, cfp->cf_size)) {
 		cvsync_fclose(cfp);
 		return (false);
 	}
@@ -569,7 +569,7 @@ filescan_rcs_update(struct filescan_args *fsa)
 
 	if ((cfp = cvsync_fopen(fsa->fsa_path)) == NULL)
 		return (filescan_rcs_replace(fsa));
-	if (!cvsync_mmap(cfp, 0, cfp->cf_size)) {
+	if (!cvsync_mmap(cfp, (off_t)0, cfp->cf_size)) {
 		cvsync_fclose(cfp);
 		return (false);
 	}
