@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2002-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2002-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -83,7 +83,7 @@ filescan_rdiff_update(struct filescan_args *fsa, struct cvsync_file *cfp)
 		return (false);
 
 	sp = cfp->cf_addr;
-	bp = sp + cfp->cf_size;
+	bp = sp + (size_t)cfp->cf_size;
 
 	while (sp < bp) {
 		if ((len = (size_t)(bp - sp)) > bsize)
