@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2003,2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2003-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,9 @@
 #include "hash.h"
 
 bool cvsync_MD5_init(void **);
+bool cvsync_RIPEMD160_init(void **);
 bool cvsync_SHA1_init(void **);
+bool cvsync_TIGER192_init(void **);
 void cvsync_mhash_update(void *, const void *, size_t);
 void cvsync_mhash_final(void *, uint8_t *);
 void cvsync_mhash_destroy(void *);
@@ -49,12 +51,24 @@ const struct hash_args MD5_args = {
 	16
 };
 
+const struct hash_args RIPEMD160_args = {
+	cvsync_RIPEMD160_init, cvsync_mhash_update, cvsync_mhash_final,
+	cvsync_mhash_destroy,
+	20
+};
+
 const struct hash_args SHA1_args = {
 	cvsync_SHA1_init, cvsync_mhash_update, cvsync_mhash_final,
 	cvsync_mhash_destroy,
 	20
 };
 
+const struct hash_args TIGER192_args = {
+	cvsync_TIGER192_init, cvsync_mhash_update, cvsync_mhash_final,
+	cvsync_mhash_destroy,
+	20
+};
+
 bool
 cvsync_MD5_init(void **ctx)
 {
@@ -68,6 +82,19 @@ cvsync_MD5_init(void **ctx)
 	return (true);
 }
 
+bool
+cvsync_RIPEMD160_init(void **ctx)
+{
+	MHASH mhashctx;
+
+	if ((mhashctx = mhash_init(MHASH_RIPEMD160)) == MHASH_FAILED)
+		return (false);
+
+	*ctx = mhashctx;
+
+	return (true);
+}
+
 bool
 cvsync_SHA1_init(void **ctx)
 {
@@ -81,6 +108,19 @@ cvsync_SHA1_init(void **ctx)
 	return (true);
 }
 
+bool
+cvsync_TIGER192_init(void **ctx)
+{
+	MHASH mhashctx;
+
+	if ((mhashctx = mhash_init(MHASH_TIGER)) == MHASH_FAILED)
+		return (false);
+
+	*ctx = mhashctx;
+
+	return (true);
+}
+
 void
 cvsync_mhash_update(void *ctx, const void *buffer, size_t bufsize)
 {
