@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2003,2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2003-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -69,7 +69,7 @@ inet_pton(int af, const char *src, void *dst)
 	if (n != 3)
 		return (0);
 
-	memcpy(dst, &addr, sizeof(addr));
+	(void)memcpy(dst, &addr, sizeof(addr));
 
 	return (1);
 }
