@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -160,7 +160,7 @@ mux_abort(struct mux *mx)
 		return;
 	}
 
-	shutdown(mx->mx_socket, SHUT_RDWR);
+	(void)shutdown(mx->mx_socket, SHUT_RDWR);
 	mx->mx_isconnected = false;
 
 	pthread_mutex_unlock(&mx->mx_lock);
@@ -285,7 +285,8 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 	}
 
 	if (mxb->mxb_length + bufsize < mxb->mxb_size) {
-		memcpy(&mxb->mxb_buffer[mxb->mxb_length], buffer, bufsize);
+		(void)memcpy(&mxb->mxb_buffer[mxb->mxb_length], buffer,
+			     bufsize);
 		mxb->mxb_length += bufsize;
 
 		if ((err = pthread_mutex_unlock(&mxb->mxb_lock)) != 0) {
@@ -417,7 +418,8 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 
 		switch (mx->mx_compress) {
 		case CVSYNC_COMPRESS_NO:
-			if (!mux_send_raw(mx, chnum, sp, mxb->mxb_size)) {
+			if (!mux_send_raw(mx, chnum, sp,
+					  (size_t)mxb->mxb_size)) {
 				pthread_mutex_unlock(&mx->mx_lock);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
@@ -425,7 +427,8 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 			}
 			break;
 		case CVSYNC_COMPRESS_ZLIB:
-			if (!mux_send_zlib(mx, chnum, sp, mxb->mxb_size)) {
+			if (!mux_send_zlib(mx, chnum, sp,
+					   (size_t)mxb->mxb_size)) {
 				pthread_mutex_unlock(&mx->mx_lock);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
@@ -455,7 +458,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 	}
 
 	if (bufsize > 0) {
-		memcpy(mxb->mxb_buffer, sp, bufsize);
+		(void)memcpy(mxb->mxb_buffer, sp, bufsize);
 		mxb->mxb_length += bufsize;
 	}
 
@@ -519,9 +522,9 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 			len2 = 0;
 		len1 = len - len2;
 
-		memcpy(sp, &mxb->mxb_buffer[mxb->mxb_head], len1);
+		(void)memcpy(sp, &mxb->mxb_buffer[mxb->mxb_head], len1);
 		if (len2 > 0)
-			memcpy(&sp[len1], mxb->mxb_buffer, len2);
+			(void)memcpy(&sp[len1], mxb->mxb_buffer, len2);
 		mxb->mxb_head += len;
 		if (mxb->mxb_head >= mxb->mxb_bufsize)
 			mxb->mxb_head -= mxb->mxb_bufsize;
