@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2003,2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2003-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -71,7 +71,7 @@ sock_init(int *socks)
 	}
 	if (kevent(__kq, __changelist, __nchanges, NULL, 0, NULL) == -1) {
 		logmsg_err("Socket Error: kqueue: %s", strerror(errno));
-		close(__kq);
+		(void)close(__kq);
 		free(__changelist);
 		return (false);
 	}
@@ -110,7 +110,8 @@ sock_accept(void)
 	int sock = -1, i;
 
 	for (i = 0 ; i < __nevents ; i++) {
-		if ((sock = accept(__changelist[i].ident, NULL, NULL)) == -1) {
+		if ((sock = accept((int)__changelist[i].ident, NULL,
+				   NULL)) == -1) {
 			if (errno == EINTR) {
 				logmsg_intr();
 				return (-1);
