@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,7 @@
 #include <time.h>
 
 #include "compat_stdbool.h"
+#include "compat_stdint.h"
 
 #include "rcslib.h"
 
@@ -131,14 +132,14 @@ struct rcslib_file *
 rcslib_init(void *addr, off_t addrlen)
 {
 	struct rcslib_file *rcs;
-	char *sp = addr, *bp = sp + addrlen - 1;
+	char *sp = addr, *bp = sp + (size_t)(addrlen - 1);
 
 	if ((addrlen == 0) || (*bp != '\n'))
 		return (NULL);
 
 	if ((rcs = malloc(sizeof(*rcs))) == NULL)
 		return (NULL);
-	memset(rcs, 0, sizeof(*rcs));
+	(void)memset(rcs, 0, sizeof(*rcs));
 
 	if (!rcslib_parse_rcstext(rcs, sp, bp)) {
 		free(rcs);
@@ -412,12 +413,12 @@ rcslib_parse_delta(struct rcslib_file *rcs, char *sp, const char *bp)
 				return (NULL);
 			}
 			if (size > 0) {
-				memcpy(rev, delta->rd_rev,
-				       size * RCSLIB_REVISION_SIZE);
+				(void)memcpy(rev, delta->rd_rev,
+					     size * RCSLIB_REVISION_SIZE);
 				free(delta->rd_rev);
 			}
-			memset(rev + size, 0,
-			       (new - size) * RCSLIB_REVISION_SIZE);
+			(void)memset(rev + size, 0,
+				     (new - size) * RCSLIB_REVISION_SIZE);
 			delta->rd_rev = rev;
 			delta->rd_size = new;
 		}
@@ -705,7 +706,8 @@ rcslib_parse_access(char *sp, const char *bp, struct rcslib_access *access)
 				return (NULL);
 			}
 			if (size > 0) {
-				memcpy(id, access->ra_id, size * RCSID_SIZE);
+				(void)memcpy(id, access->ra_id,
+					     size * RCSID_SIZE);
 				free(access->ra_id);
 			}
 			access->ra_id = id;
@@ -783,8 +785,8 @@ rcslib_parse_symbols(char *sp, const char *bp, struct rcslib_symbols *symbols)
 				return (NULL);
 			}
 			if (size > 0) {
-				memcpy(sym, symbols->rs_symbols,
-				       size * RCSLIB_SYMBOL_SIZE);
+				(void)memcpy(sym, symbols->rs_symbols,
+					     size * RCSLIB_SYMBOL_SIZE);
 				free(symbols->rs_symbols);
 			}
 			symbols->rs_symbols = sym;
@@ -863,8 +865,8 @@ rcslib_parse_locks(char *sp, const char *bp, struct rcslib_locks *locks)
 				return (NULL);
 			}
 			if (size > 0) {
-				memcpy(lock, locks->rl_locks,
-				       size * RCSLIB_LOCK_SIZE);
+				(void)memcpy(lock, locks->rl_locks,
+					     size * RCSLIB_LOCK_SIZE);
 				free(locks->rl_locks);
 			}
 			locks->rl_locks = lock;
@@ -1101,8 +1103,8 @@ rcslib_parse_branches(char *sp, const char *bp,
 				return (NULL);
 			}
 			if (size > 0) {
-				memcpy(num, branches->rb_num,
-				       size * RCSNUM_SIZE);
+				(void)memcpy(num, branches->rb_num,
+					     size * RCSNUM_SIZE);
 				free(branches->rb_num);
 			}
 			branches->rb_num = num;
@@ -1473,7 +1475,7 @@ rcslib_write_delta(int fd, const struct rcslib_revision *rev)
 {
 	const struct rcslib_branches *branches = &rev->branches;
 	struct iovec iov[8];
-	size_t i;
+	size_t len, i;
 	ssize_t wn;
 
 	iov[0].iov_base = rev->num.n_str;
@@ -1495,10 +1497,13 @@ rcslib_write_delta(int fd, const struct rcslib_revision *rev)
 	iov[6].iov_len = rev->state.i_len;
 	iov[7].iov_base = ";\nbranches";
 	iov[7].iov_len = 10;
-	wn = rev->num.n_len + rev->date.rd_num.n_len + rev->author.i_len +
-	     rev->state.i_len + iov[5].iov_len + 25;
+	len = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len +
+	      iov[3].iov_len + iov[4].iov_len + iov[5].iov_len +
+	      iov[6].iov_len + iov[7].iov_len;
 
-	if (writev(fd, iov, 8) != wn)
+	if ((wn = writev(fd, iov, 8)) == -1)
+		return (false);
+	if ((size_t)wn != len)
 		return (false);
 
 	iov[0].iov_base = "\n\t";
@@ -1506,7 +1511,10 @@ rcslib_write_delta(int fd, const struct rcslib_revision *rev)
 	for (i = 0 ; i < branches->rb_count ; i++) {
 		iov[1].iov_base = branches->rb_num[i].n_str;
 		iov[1].iov_len = branches->rb_num[i].n_len;
-		if (writev(fd, iov, 2) != branches->rb_num[i].n_len + 2)
+		len = iov[0].iov_len + iov[1].iov_len;
+		if ((wn = writev(fd, iov, 2)) == -1)
+			return (false);
+		if ((size_t)wn != len)
 			return (false);
 	}
 
@@ -1516,7 +1524,10 @@ rcslib_write_delta(int fd, const struct rcslib_revision *rev)
 	iov[1].iov_len = rev->next.n_len;
 	iov[2].iov_base = ";\n\n";
 	iov[2].iov_len = 3;
-	if (writev(fd, iov, 3) != rev->next.n_len + 10)
+	len = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len;
+	if ((wn = writev(fd, iov, 3)) == -1)
+		return (false);
+	if ((size_t)wn != len)
 		return (false);
 
 	return (true);
@@ -1526,6 +1537,7 @@ bool
 rcslib_write_deltatext(int fd, const struct rcslib_revision *rev)
 {
 	struct iovec iov[7];
+	size_t len;
 	ssize_t wn;
 
 	iov[0].iov_base = "\n\n";
@@ -1542,9 +1554,13 @@ rcslib_write_deltatext(int fd, const struct rcslib_revision *rev)
 	iov[5].iov_len = rev->text.s_len;
 	iov[6].iov_base = "@\n";
 	iov[6].iov_len = 2;
-	wn = rev->num.n_len + rev->log.s_len + rev->text.s_len + 18;
+	len = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len +
+	      iov[3].iov_len + iov[4].iov_len + iov[5].iov_len +
+	      iov[6].iov_len;
 
-	if (writev(fd, iov, 7) != wn)
+	if ((wn = writev(fd, iov, 7)) == -1)
+		return (false);
+	if ((size_t)wn != len)
 		return (false);
 
 	return (true);
