@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -68,7 +68,7 @@ scanfile_init(struct scanfile_args *sa)
 	sa->sa_tmp_name[0] = '\0';
 	sa->sa_tmp_mode = 0;
 	sa->sa_dirlist = NULL;
-	memset(&sa->sa_attr, 0, sizeof(sa->sa_attr));
+	(void)memset(&sa->sa_attr, 0, sizeof(sa->sa_attr));
 	sa->sa_changed = false;
 }
 
@@ -88,13 +88,14 @@ scanfile_open(const char *fname)
 		free(sa);
 		return (NULL);
 	}
-	if (!cvsync_mmap(sa->sa_scanfile, 0, sa->sa_scanfile->cf_size)) {
+	if (!cvsync_mmap(sa->sa_scanfile, (off_t)0,
+			 sa->sa_scanfile->cf_size)) {
 		cvsync_fclose(sa->sa_scanfile);
 		free(sa);
 		return (NULL);
 	}
 	sa->sa_start = sa->sa_scanfile->cf_addr;
-	sa->sa_end = sa->sa_start + sa->sa_scanfile->cf_size;
+	sa->sa_end = sa->sa_start + (size_t)sa->sa_scanfile->cf_size;
 
 	return (sa);
 }
@@ -123,7 +124,7 @@ scanfile_read_attr(uint8_t *sp, const uint8_t *bp, struct scanfile_attr *attr)
 		return (false);
 	}
 	sp += 3;
-	if (bp - sp < attr->a_namelen) {
+	if ((size_t)(bp - sp) < attr->a_namelen) {
 		logmsg_err("Scanfile Error: read attr name");
 		return (false);
 	}
@@ -138,7 +139,7 @@ scanfile_read_attr(uint8_t *sp, const uint8_t *bp, struct scanfile_attr *attr)
 		return (false);
 	}
 	sp += 2;
-	if (bp - sp < attr->a_auxlen) {
+	if ((size_t)(bp - sp) < attr->a_auxlen) {
 		logmsg_err("Scanfile Error: read attr aux");
 		return (false);
 	}
@@ -154,7 +155,8 @@ scanfile_write_attr(struct scanfile_args *sa, struct scanfile_attr *attr)
 {
 	struct iovec iov[4];
 	uint8_t buffer1[3], buffer2[2];
-	ssize_t len;
+	size_t len;
+	ssize_t wn;
 
 	buffer1[0] = attr->a_type;
 	SetWord(&buffer1[1], attr->a_namelen);
@@ -168,9 +170,13 @@ scanfile_write_attr(struct scanfile_args *sa, struct scanfile_attr *attr)
 	iov[2].iov_len = 2;
 	iov[3].iov_base = attr->a_aux;
 	iov[3].iov_len = attr->a_auxlen;
-
-	len = attr->a_namelen + attr->a_auxlen + 5;
-	if (writev(sa->sa_tmp, iov, 4) != len) {
+	len = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len +
+	      iov[3].iov_len;
+	if ((wn = writev(sa->sa_tmp, iov, 4)) == -1) {
+		logmsg_err("Scanfile Error: write attr");
+		return (false);
+	}
+	if ((size_t)wn != len) {
 		logmsg_err("Scanfile Error: write attr");
 		return (false);
 	}
@@ -218,8 +224,9 @@ scanfile_create_tmpfile(struct scanfile_args *sa, mode_t mode)
 	else
 		len = 0;
 	if (len > 0)
-		memcpy(sa->sa_tmp_name, sa->sa_scanfile_name, len);
-	memcpy(&sa->sa_tmp_name[len], CVSYNC_TMPFILE, CVSYNC_TMPFILE_LEN);
+		(void)memcpy(sa->sa_tmp_name, sa->sa_scanfile_name, len);
+	(void)memcpy(&sa->sa_tmp_name[len], CVSYNC_TMPFILE,
+		     CVSYNC_TMPFILE_LEN);
 	sa->sa_tmp_name[len + CVSYNC_TMPFILE_LEN] = '\0';
 
 	if ((sa->sa_tmp = mkstemp(sa->sa_tmp_name)) == -1) {
@@ -231,8 +238,8 @@ scanfile_create_tmpfile(struct scanfile_args *sa, mode_t mode)
 
 	if ((sa->sa_dirlist = list_init()) == NULL) {
 		logmsg_err("Scanfile Error: list init");
-		unlink(sa->sa_tmp_name);
-		close(sa->sa_tmp);
+		(void)unlink(sa->sa_tmp_name);
+		(void)close(sa->sa_tmp);
 		return (false);
 	}
 	list_set_destructor(sa->sa_dirlist, free);
@@ -247,9 +254,9 @@ scanfile_remove_tmpfile(struct scanfile_args *sa)
 		return;
 
 	if (sa->sa_tmp != -1)
-		close(sa->sa_tmp);
+		(void)close(sa->sa_tmp);
 	if (strlen(sa->sa_tmp_name) != 0)
-		unlink(sa->sa_tmp_name);
+		(void)unlink(sa->sa_tmp_name);
 	if (sa->sa_dirlist != NULL)
 		list_destroy(sa->sa_dirlist);
 }
@@ -524,7 +531,7 @@ scanfile_insert_attr(struct scanfile_args *sa, struct scanfile_attr *attr)
 		logmsg_err("%s", strerror(errno));
 		return (false);
 	}
-	memcpy(dirattr, attr, sizeof(*dirattr));
+	(void)memcpy(dirattr, attr, sizeof(*dirattr));
 
 	if (!list_insert_tail(sa->sa_dirlist, dirattr)) {
 		free(dirattr);
