@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -130,8 +130,8 @@ scanfile_rcs_init(struct scanfile_create_args *sca)
 	sra->sra_path[sra->sra_pathlen] = '\0';
 	sra->sra_rpath = &sra->sra_path[sra->sra_pathlen];
 	if (sra->sra_rprefixlen > 0) {
-		memcpy(sra->sra_rprefix, sca->sca_rprefix,
-		       sca->sca_rprefixlen);
+		(void)memcpy(sra->sra_rprefix, sca->sca_rprefix,
+			     sca->sca_rprefixlen);
 	}
 	sra->sra_mdirent_args = sca->sca_mdirent_args;
 	sra->sra_umask = sca->sca_umask;
@@ -218,8 +218,8 @@ scanfile_rcs(struct scanfile_create_args *sca)
 					scanfile_rcs_destroy(sra);
 					return (false);
 				}
-				memcpy(&sra->sra_path[sra->sra_pathlen],
-				       mdp->md_name, mdp->md_namelen);
+				(void)memcpy(&sra->sra_path[sra->sra_pathlen],
+					     mdp->md_name, mdp->md_namelen);
 				sra->sra_path[len - 1] = '/';
 				sra->sra_path[len] = '\0';
 
@@ -295,7 +295,7 @@ scanfile_rcs_dir(struct scanfile_rcs_args *sra, struct mdirent_rcs *mdp)
 	rpathlen = sra->sra_pathlen - (sra->sra_rpath - sra->sra_path);
 	if ((namelen = rpathlen + mdp->md_namelen) >= sra->sra_pathmax)
 		return (false);
-	memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
+	(void)memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
 
 	if ((auxlen = attr_rcs_encode_dir(sra->sra_aux, sra->sra_auxmax,
 					  mode)) == 0) {
@@ -326,7 +326,7 @@ scanfile_rcs_file(struct scanfile_rcs_args *sra, struct mdirent_rcs *mdp)
 	rpathlen = sra->sra_pathlen - (sra->sra_rpath - sra->sra_path);
 	if ((namelen = rpathlen + mdp->md_namelen) >= sra->sra_pathmax)
 		return (false);
-	memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
+	(void)memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
 	if (IS_FILE_RCS(mdp->md_name, mdp->md_namelen)) {
 		if (mdp->md_attic)
 			attr->a_type = FILETYPE_RCS_ATTIC;
@@ -368,7 +368,7 @@ scanfile_rcs_symlink(struct scanfile_rcs_args *sra, struct mdirent_rcs *mdp)
 	rpathlen = sra->sra_pathlen - (sra->sra_rpath - sra->sra_path);
 	if ((namelen = rpathlen + mdp->md_namelen) >= sra->sra_pathmax)
 		return (false);
-	memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
+	(void)memcpy(&sra->sra_rpath[rpathlen], mdp->md_name, mdp->md_namelen);
 	sra->sra_rpath[rpathlen + mdp->md_namelen] = '\0';
 	if ((auxlen = readlink(sra->sra_path, (char *)sra->sra_aux,
 			       sra->sra_auxmax)) == -1) {
@@ -418,7 +418,7 @@ scanfile_rcs_opendir(struct scanfile_rcs_args *sra, size_t pathlen)
 		free(mdp);
 		return (NULL);
 	}
-	memcpy(mdp->md_name, &sra->sra_rprefix[rpathlen], len);
+	(void)memcpy(mdp->md_name, &sra->sra_rprefix[rpathlen], len);
 	mdp->md_namelen = len;
 	mdp->md_attic = false;
 	mdp->md_dead = false;
@@ -427,8 +427,8 @@ scanfile_rcs_opendir(struct scanfile_rcs_args *sra, size_t pathlen)
 		free(mdp);
 		return (NULL);
 	}
-	memcpy(&sra->sra_path[pathlen], &sra->sra_rprefix[rpathlen],
-	       mdp->md_namelen);
+	(void)memcpy(&sra->sra_path[pathlen], &sra->sra_rprefix[rpathlen],
+		     mdp->md_namelen);
 	sra->sra_path[len] = '\0';
 
 	if (sra->sra_mdirent_args->mda_symfollow)
