@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -277,7 +277,7 @@ updater_rcs_fetch(struct updater_args *uda)
 	if ((pathlen = uda->uda_pathlen + cap->ca_namelen) >= uda->uda_pathmax)
 		return (false);
 
-	memcpy(uda->uda_rpath, cap->ca_name, cap->ca_namelen);
+	(void)memcpy(uda->uda_rpath, cap->ca_name, cap->ca_namelen);
 	uda->uda_rpath[cap->ca_namelen] = '\0';
 	if (cap->ca_type == FILETYPE_RCS_ATTIC) {
 		if (!cvsync_rcs_insert_attic(uda->uda_path, pathlen,
@@ -414,8 +414,9 @@ updater_rcs_add_file(struct updater_args *uda)
 		ep--;
 	}
 	len = ep - uda->uda_path;
-	memcpy(uda->uda_tmpfile, uda->uda_path, len);
-	memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE, CVSYNC_TMPFILE_LEN);
+	(void)memcpy(uda->uda_tmpfile, uda->uda_path, len);
+	(void)memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE,
+		     CVSYNC_TMPFILE_LEN);
 	uda->uda_tmpfile[len + CVSYNC_TMPFILE_LEN] = '\0';
 
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, 2))
@@ -436,8 +437,8 @@ updater_rcs_add_file(struct updater_args *uda)
 
 	if (!(*hashops->init)(&uda->uda_hash_ctx)) {
 		logmsg_err("%s: hash init", uda->uda_path);
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 
@@ -452,20 +453,25 @@ updater_rcs_add_file(struct updater_args *uda)
 		if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN,
 			      uda->uda_buffer, len)) {
 			(*hashops->destroy)(uda->uda_hash_ctx);
-			unlink(uda->uda_tmpfile);
-			close(fd);
+			(void)unlink(uda->uda_tmpfile);
+			(void)close(fd);
 			return (false);
 		}
 
 		if ((wn = write(fd, uda->uda_buffer, len)) == -1) {
 			logmsg_err("%s: %s", uda->uda_path, strerror(errno));
 			(*hashops->destroy)(uda->uda_hash_ctx);
-			unlink(uda->uda_tmpfile);
-			close(fd);
+			(void)unlink(uda->uda_tmpfile);
+			(void)close(fd);
+			return (false);
+		}
+		if ((size_t)wn != len) {
+			logmsg_err("%s: write error", uda->uda_path);
+			(*hashops->destroy)(uda->uda_hash_ctx);
+			(void)unlink(uda->uda_tmpfile);
+			(void)close(fd);
 			return (false);
 		}
-		if ((size_t)wn != len)
-			break;
 
 		(*hashops->update)(uda->uda_hash_ctx, uda->uda_buffer, len);
 
@@ -474,51 +480,51 @@ updater_rcs_add_file(struct updater_args *uda)
 	if (size > 0) {
 		logmsg_err("%s: residue %" PRIu64, uda->uda_path, size);
 		(*hashops->destroy)(uda->uda_hash_ctx);
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 
 	(*hashops->final)(uda->uda_hash_ctx, uda->uda_hash);
 
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, hashops->length)) {
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 	if (memcmp(uda->uda_hash, cmd, hashops->length) != 0) {
 		logmsg_err("Updater Error: rcs: %s: hash mismatch",
 			   uda->uda_path);
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, 3)) {
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 	if (GetWord(cmd) != 1) {
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 	if (cmd[2] != UPDATER_END) {
-		unlink(uda->uda_tmpfile);
-		close(fd);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(fd);
 		return (false);
 	}
 
 	if (fchmod(fd, cap->ca_mode) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
 	if (close(fd) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
@@ -527,13 +533,13 @@ updater_rcs_add_file(struct updater_args *uda)
 
 	if (utime(uda->uda_tmpfile, &times) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
 	if (rename(uda->uda_tmpfile, uda->uda_path) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
@@ -564,7 +570,7 @@ updater_rcs_add_symlink(struct updater_args *uda)
 		return (false);
 	}
 
-	memcpy(cap->ca_aux, cmd, len);
+	(void)memcpy(cap->ca_aux, cmd, len);
 	cap->ca_auxlen = len;
 
 	if (!updater_rcs_scanfile_create(uda))
@@ -685,8 +691,9 @@ updater_rcs_attic(struct updater_args *uda)
 		ep--;
 	}
 	len = ep - uda->uda_path;
-	memcpy(uda->uda_tmpfile, uda->uda_path, len);
-	memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE, CVSYNC_TMPFILE_LEN);
+	(void)memcpy(uda->uda_tmpfile, uda->uda_path, len);
+	(void)memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE,
+		     CVSYNC_TMPFILE_LEN);
 	uda->uda_tmpfile[len + CVSYNC_TMPFILE_LEN] = '\0';
 
 	switch (cap->ca_type) {
@@ -760,7 +767,7 @@ updater_rcs_attic(struct updater_args *uda)
 	if (unlink(uda->uda_path) == -1) {
 		if (errno != ENOENT) {
 			logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-			unlink(uda->uda_tmpfile);
+			(void)unlink(uda->uda_tmpfile);
 			return (false);
 		}
 	}
@@ -809,7 +816,7 @@ updater_rcs_attic(struct updater_args *uda)
 
 	if (rename(uda->uda_tmpfile, uda->uda_path) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
@@ -902,8 +909,9 @@ updater_rcs_update(struct updater_args *uda)
 		ep--;
 	}
 	len = ep - uda->uda_path;
-	memcpy(uda->uda_tmpfile, uda->uda_path, len);
-	memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE, CVSYNC_TMPFILE_LEN);
+	(void)memcpy(uda->uda_tmpfile, uda->uda_path, len);
+	(void)memcpy(&uda->uda_tmpfile[len], CVSYNC_TMPFILE,
+		     CVSYNC_TMPFILE_LEN);
 	uda->uda_tmpfile[len + CVSYNC_TMPFILE_LEN] = '\0';
 
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, 3))
@@ -931,7 +939,7 @@ updater_rcs_update(struct updater_args *uda)
 
 	if (rename(uda->uda_tmpfile, uda->uda_path) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 	if ((unlink(uda->uda_tmpfile) == -1) && (errno != ENOENT)) {
@@ -966,21 +974,21 @@ updater_rcs_update_rcs(struct updater_args *uda)
 	}
 
 	if ((cfp = cvsync_fopen(uda->uda_path)) == NULL) {
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 	if (!cvsync_mmap(cfp, 0, cfp->cf_size)) {
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 
 	if ((rcs = rcslib_init(cfp->cf_addr, cfp->cf_size)) == NULL) {
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 
@@ -988,53 +996,53 @@ updater_rcs_update_rcs(struct updater_args *uda)
 		logmsg_err("Updater(RCS): UPDATE(admin): error");
 		rcslib_destroy(rcs);
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 	if (!updater_rcs_delta(uda, rcs)) {
 		logmsg_err("Updater(RCS): UPDATE(delta): error");
 		rcslib_destroy(rcs);
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 	if (!updater_rcs_desc(uda)) {
 		logmsg_err("Updater(RCS): UPDATE(desc): error");
 		rcslib_destroy(rcs);
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 	if (!updater_rcs_deltatext(uda, rcs)) {
 		logmsg_err("Updater(RCS): UPDATE(deltatext): error");
 		rcslib_destroy(rcs);
 		cvsync_fclose(cfp);
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 
 	rcslib_destroy(rcs);
 
 	if (!cvsync_fclose(cfp)) {
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 
 	if (fchmod(uda->uda_fileno, cap->ca_mode) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
-		close(uda->uda_fileno);
+		(void)unlink(uda->uda_tmpfile);
+		(void)close(uda->uda_fileno);
 		return (false);
 	}
 
 	if (close(uda->uda_fileno) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
@@ -1043,7 +1051,7 @@ updater_rcs_update_rcs(struct updater_args *uda)
 
 	if (utime(uda->uda_tmpfile, &times) == -1) {
 		logmsg_err("%s: %s", uda->uda_path, strerror(errno));
-		unlink(uda->uda_tmpfile);
+		(void)unlink(uda->uda_tmpfile);
 		return (false);
 	}
 
@@ -1057,7 +1065,7 @@ updater_rcs_update_symlink(struct updater_args *uda)
 
 	if (cap->ca_auxlen >= uda->uda_pathmax)
 		return (false);
-	memcpy(uda->uda_symlink, cap->ca_aux, cap->ca_auxlen);
+	(void)memcpy(uda->uda_symlink, cap->ca_aux, cap->ca_auxlen);
 	uda->uda_symlink[cap->ca_auxlen] = '\0';
 
 	if (unlink(uda->uda_path) == -1) {
@@ -1086,7 +1094,7 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 	struct rcssym *s1, *s2;
 	struct iovec iov[4];
 	uint8_t *cmd = uda->uda_cmd;
-	size_t len, c;
+	size_t len, iovlen, c;
 	ssize_t wn;
 	int fd = uda->uda_fileno, rv;
 
@@ -1109,7 +1117,7 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 	if (cmd[0] == UPDATER_UPDATE_RCS_HEAD) {
 		if ((len < 2) || (len != (size_t)cmd[1] + 2))
 			return (false);
-		memcpy(uda->uda_buffer, &cmd[2], cmd[1]);
+		(void)memcpy(uda->uda_buffer, &cmd[2], cmd[1]);
 		iov[1].iov_base = uda->uda_buffer;
 		iov[1].iov_len = cmd[1];
 
@@ -1130,18 +1138,23 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 		iov[0].iov_len = 4;
 	iov[2].iov_base = ";\n";
 	iov[2].iov_len = 2;
+	iovlen = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len;
 
-	if (writev(fd, iov, 3) != iov[0].iov_len + iov[1].iov_len + 2) {
+	if ((wn = writev(fd, iov, 3)) == -1) {
 		logmsg_err("%s", strerror(errno));
 		return (false);
 	}
+	if ((size_t)wn != iovlen) {
+		logmsg_err("writev error");
+		return (false);
+	}
 
 	/* branch */
 	if (cmd[0] == UPDATER_UPDATE_RCS_BRANCH) {
 		if ((len < 2) || (len != (size_t)cmd[1] + 2))
 			return (false);
 		if (cmd[1] > 0) {
-			memcpy(uda->uda_buffer, &cmd[2], cmd[1]);
+			(void)memcpy(uda->uda_buffer, &cmd[2], cmd[1]);
 			iov[1].iov_base = uda->uda_buffer;
 			iov[1].iov_len = cmd[1];
 		} else {
@@ -1168,11 +1181,16 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 		iov[0].iov_len = 7;
 		iov[2].iov_base = ";\n";
 		iov[2].iov_len = 2;
+		iovlen = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len;
 
-		if (writev(fd, iov, 3) != iov[1].iov_len + 9) {
+		if ((wn = writev(fd, iov, 3)) == -1) {
 			logmsg_err("%s", strerror(errno));
 			return (false);
 		}
+		if ((size_t)wn != iovlen) {
+			logmsg_err("writev error");
+			return (false);
+		}
 	}
 
 	/* access */
@@ -1218,10 +1236,14 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 			}
 			iov[1].iov_base = i2->i_id;
 			iov[1].iov_len = i2->i_len;
-			if (writev(fd, iov, 2) != i2->i_len + 2) {
+			if ((wn = writev(fd, iov, 2)) == -1) {
 				logmsg_err("%s", strerror(errno));
 				return (false);
 			}
+			if ((size_t)wn != i2->i_len + 2) {
+				logmsg_err("writev error");
+				return (false);
+			}
 			break;
 		case UPDATER_UPDATE_REMOVE:
 			if (c == rcs->access.ra_count)
@@ -1236,10 +1258,14 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 				}
 				iov[1].iov_base = i1->i_id;
 				iov[1].iov_len = i1->i_len;
-				if (writev(fd, iov, 2) != i1->i_len + 2) {
+				if ((wn = writev(fd, iov, 2)) == -1) {
 					logmsg_err("%s", strerror(errno));
 					return (false);
 				}
+				if ((size_t)wn != i1->i_len + 2) {
+					logmsg_err("writev error");
+					return (false);
+				}
 			} while (++c < rcs->access.ra_count);
 			break;
 		default:
@@ -1258,10 +1284,14 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 		i1 = &rcs->access.ra_id[c++];
 		iov[1].iov_base = i1->i_id;
 		iov[1].iov_len = i1->i_len;
-		if (writev(fd, iov, 2) != i1->i_len + 2) {
+		if ((wn = writev(fd, iov, 2)) == -1) {
 			logmsg_err("%s", strerror(errno));
 			return (false);
 		}
+		if ((size_t)wn != i1->i_len + 2) {
+			logmsg_err("writev error");
+			return (false);
+		}
 	}
 
 	if (write(fd, ";\nsymbols", 9) != 9) {
@@ -1279,7 +1309,7 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 			return (false);
 		if ((cmd[2] == 0) || (cmd[3] == 0))
 			return (false);
-		if (len != cmd[2] + cmd[3] + 4)
+		if (len != (size_t)cmd[2] + (size_t)cmd[3] + 4)
 			return (false);
 		s2->s_sym = (char *)&cmd[4];
 		s2->s_len = cmd[2];
@@ -1417,7 +1447,7 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 			return (false);
 		if ((cmd[2] == 0) || (cmd[3] == 0))
 			return (false);
-		if (len != cmd[2] + cmd[3] + 4)
+		if (len != (size_t)cmd[2] + (size_t)cmd[3] + 4)
 			return (false);
 		i2->i_id = (char *)&cmd[4];
 		i2->i_len = cmd[2];
@@ -1553,10 +1583,14 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 		if (rcs->comment.s_len > 0) {
 			iov[1].iov_base = rcs->comment.s_str;
 			iov[1].iov_len = rcs->comment.s_len;
-			if (writev(fd, iov, 3) != rcs->comment.s_len + 12) {
+			if ((wn = writev(fd, iov, 3)) == -1) {
 				logmsg_err("%s", strerror(errno));
 				return (false);
 			}
+			if ((size_t)wn != rcs->comment.s_len + 12) {
+				logmsg_err("writev error");
+				return (false);
+			}
 		}
 	}
 
@@ -1588,10 +1622,14 @@ updater_rcs_admin(struct updater_args *uda, struct rcslib_file *rcs)
 		if (rcs->expand.s_len > 0) {
 			iov[1].iov_base = rcs->expand.s_str;
 			iov[1].iov_len = rcs->expand.s_len;
-			if (writev(fd, iov, 3) != rcs->expand.s_len + 11) {
+			if ((wn = writev(fd, iov, 3)) == -1) {
 				logmsg_err("%s", strerror(errno));
 				return (false);
 			}
+			if ((size_t)wn != rcs->expand.s_len + 11) {
+				logmsg_err("writev error");
+				return (false);
+			}
 		}
 	}
 
@@ -1638,7 +1676,7 @@ updater_rcs_delta(struct updater_args *uda, struct rcslib_file *rcs)
 
 		switch (cmd[1]) {
 		case UPDATER_UPDATE_ADD:
-			if ((cmd[2] == 0) || (len < cmd[2] + 3))
+			if ((cmd[2] == 0) || (len < (size_t)cmd[2] + 3))
 				return (false);
 			if (!rcslib_str2num(&cmd[3], cmd[2], n2))
 				return (false);
@@ -1666,7 +1704,7 @@ updater_rcs_delta(struct updater_args *uda, struct rcslib_file *rcs)
 				return (false);
 			break;
 		case UPDATER_UPDATE_REMOVE:
-			if ((cmd[2] == 0) || (len != cmd[2] + 3))
+			if ((cmd[2] == 0) || (len != (size_t)cmd[2] + 3))
 				return (false);
 			if (!rcslib_str2num(&cmd[3], cmd[2], n2))
 				return (false);
@@ -1688,7 +1726,7 @@ updater_rcs_delta(struct updater_args *uda, struct rcslib_file *rcs)
 			} while (++c < rcs->delta.rd_count);
 			break;
 		case UPDATER_UPDATE_UPDATE:
-			if ((cmd[2] == 0) || (len < cmd[2] + 3))
+			if ((cmd[2] == 0) || (len < (size_t)cmd[2] + 3))
 				return (false);
 			if (!rcslib_str2num(&cmd[3], cmd[2], n2))
 				return (false);
@@ -1858,11 +1896,16 @@ updater_rcs_write_delta(struct updater_args *uda, uint8_t *sp, size_t len)
 		}
 		iov[1].iov_base = (void *)sp;
 		iov[1].iov_len = slen;
-		if (writev(uda->uda_fileno, iov, 2) != slen + 2) {
+		if ((wn = writev(uda->uda_fileno, iov, 2)) == -1) {
 			logmsg_err("%s", strerror(errno));
 			(*hashops->destroy)(uda->uda_hash_ctx);
 			return (false);
 		}
+		if ((size_t)wn != slen + 2) {
+			logmsg_err("writev error");
+			(*hashops->destroy)(uda->uda_hash_ctx);
+			return (false);
+		}
 		(*hashops->update)(uda->uda_hash_ctx, sp, slen);
 		sp += slen;
 		if ((len -= slen + 1) == 0) {
@@ -1890,11 +1933,16 @@ updater_rcs_write_delta(struct updater_args *uda, uint8_t *sp, size_t len)
 	iov[2].iov_base = ";\n\n";
 	iov[2].iov_len = 3;
 
-	if (writev(uda->uda_fileno, iov, 3) != slen + 10) {
+	if ((wn = writev(uda->uda_fileno, iov, 3)) == -1) {
 		logmsg_err("%s", strerror(errno));
 		(*hashops->destroy)(uda->uda_hash_ctx);
 		return (false);
 	}
+	if ((size_t)wn != slen + 10) {
+		logmsg_err("writev error");
+		(*hashops->destroy)(uda->uda_hash_ctx);
+		return (false);
+	}
 
 	if (len != hashops->length) {
 		(*hashops->destroy)(uda->uda_hash_ctx);
@@ -1929,17 +1977,22 @@ updater_rcs_desc(struct updater_args *uda)
 		return (false);
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, len - 1))
 		return (false);
-	if ((iov[1].iov_len = cmd[0]) != len - 2)
+	if ((size_t)cmd[0] != len - 2)
 		return (false);
 	iov[1].iov_base = (void *)&cmd[1];
+	iov[1].iov_len = len - 2;
 	iov[2].iov_base = "@\n";
 	iov[2].iov_len = 2;
-	wn = iov[1].iov_len + 10;
+	len = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len;
 
-	if (writev(uda->uda_fileno, iov, 3) != wn) {
+	if ((wn = writev(uda->uda_fileno, iov, 3)) == -1) {
 		logmsg_err("%s", strerror(errno));
 		return (false);
 	}
+	if ((size_t)wn != len) {
+		logmsg_err("writev error");
+		return (false);
+	}
 
 	return (true);
 }
@@ -1971,7 +2024,7 @@ updater_rcs_deltatext(struct updater_args *uda, struct rcslib_file *rcs)
 			return (false);
 		if (cmd[0] != UPDATER_UPDATE_RCS_DELTATEXT)
 			return (false);
-		if ((cmd[2] == 0) || (len != cmd[2] + 3))
+		if ((cmd[2] == 0) || (len != (size_t)cmd[2] + 3))
 			return (false);
 		if (!rcslib_str2num(&cmd[3], cmd[2], n2))
 			return (false);
@@ -2061,6 +2114,7 @@ updater_rcs_write_deltatext(struct updater_args *uda, struct rcsnum *num)
 	uint32_t loglen;
 	uint8_t *cmd = uda->uda_cmd;
 	size_t len;
+	ssize_t wn;
 	int fd = uda->uda_fileno;
 
 	if (!(*hashops->init)(&uda->uda_hash_ctx))
@@ -2072,11 +2126,16 @@ updater_rcs_write_deltatext(struct updater_args *uda, struct rcsnum *num)
 	iov[1].iov_len = num->n_len;
 	iov[2].iov_base = "\nlog\n@";
 	iov[2].iov_len = 6;
-	if (writev(fd, iov, 3) != num->n_len + 8) {
+	if ((wn = writev(fd, iov, 3)) == -1) {
 		logmsg_err("%s", strerror(errno));
 		(*hashops->destroy)(uda->uda_hash_ctx);
 		return (false);
 	}
+	if ((size_t)wn != num->n_len + 8) {
+		logmsg_err("writev error");
+		(*hashops->destroy)(uda->uda_hash_ctx);
+		return (false);
+	}
 
 	if (!mux_recv(uda->uda_mux, MUX_UPDATER_IN, cmd, 4)) {
 		(*hashops->destroy)(uda->uda_hash_ctx);
@@ -2093,11 +2152,16 @@ updater_rcs_write_deltatext(struct updater_args *uda, struct rcsnum *num)
 				(*hashops->destroy)(uda->uda_hash_ctx);
 				return (false);
 			}
-			if (write(fd, uda->uda_buffer, len) != len) {
+			if ((wn = write(fd, uda->uda_buffer, len)) == -1) {
 				logmsg_err("%s", strerror(errno));
 				(*hashops->destroy)(uda->uda_hash_ctx);
 				return (false);
 			}
+			if ((size_t)wn != len) {
+				logmsg_err("writev error");
+				(*hashops->destroy)(uda->uda_hash_ctx);
+				return (false);
+			}
 			(*hashops->update)(uda->uda_hash_ctx,
 					   uda->uda_buffer, len);
 			loglen -= (uint32_t)len;
@@ -2125,11 +2189,16 @@ updater_rcs_write_deltatext(struct updater_args *uda, struct rcsnum *num)
 				(*hashops->destroy)(uda->uda_hash_ctx);
 				return (false);
 			}
-			if (write(fd, uda->uda_buffer, len) != len) {
+			if ((wn = write(fd, uda->uda_buffer, len)) == -1) {
 				logmsg_err("%s", strerror(errno));
 				(*hashops->destroy)(uda->uda_hash_ctx);
 				return (false);
 			}
+			if ((size_t)wn != len) {
+				logmsg_err("writev error");
+				(*hashops->destroy)(uda->uda_hash_ctx);
+				return (false);
+			}
 			(*hashops->update)(uda->uda_hash_ctx,
 					   uda->uda_buffer, len);
 			textlen -= (uint64_t)len;
