@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -291,7 +291,7 @@ config_parse_config(struct config_args *ca)
 		logmsg_err("%s", strerror(errno));
 		return (NULL);
 	}
-	memset(cf, 0, sizeof(*cf));
+	(void)memset(cf, 0, sizeof(*cf));
 	cf->cf_maxclients = (size_t)-1;
 	cf->cf_hash = HASH_UNSPEC;
 
@@ -491,7 +491,7 @@ config_parse_collection(struct config_args *ca)
 		logmsg_err("%s", strerror(errno));
 		return (NULL);
 	}
-	memset(cl, 0, sizeof(*cl));
+	(void)memset(cl, 0, sizeof(*cl));
 	cl->cl_errormode = CVSYNC_ERRORMODE_UNSPEC;
 	cl->cl_symfollow = true;
 	cl->cl_umask = CVSYNC_UMASK_UNSPEC;
@@ -769,12 +769,13 @@ config_set_collection_super(struct collection *cl, struct collection *super)
 	if (cl->cl_rprefixlen > sizeof(cl->cl_rprefix))
 		return (false);
 	if (cl->cl_rprefixlen > 0) {
-		memcpy(cl->cl_rprefix, &cl->cl_prefix[super->cl_prefixlen],
-		       cl->cl_rprefixlen);
+		(void)memcpy(cl->cl_rprefix,
+			     &cl->cl_prefix[super->cl_prefixlen],
+			     cl->cl_rprefixlen);
 		cl->cl_rprefix[cl->cl_rprefixlen] = '/';
 	}
 	cl->cl_prefixlen = super->cl_prefixlen;
-	memcpy(cl->cl_prefix, super->cl_prefix, cl->cl_prefixlen);
+	(void)memcpy(cl->cl_prefix, super->cl_prefix, cl->cl_prefixlen);
 	cl->cl_prefix[cl->cl_prefixlen] = '\0';
 
 	cl->cl_super = super;
