@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2003,2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2003-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -73,11 +73,9 @@ int64_t cvsup_decode_mtime(uint8_t *, uint8_t *, uint8_t **);
 uint64_t cvsup_decode_size(uint8_t *, uint8_t *, uint8_t **);
 size_t cvsup_decode_linktarget(uint8_t *, uint8_t *, uint8_t **, void *, size_t);
 uint16_t cvsup_decode_mode(uint8_t *, uint8_t *, uint8_t **);
-int cvsup_decode_length(uint8_t *, uint8_t *);
+size_t cvsup_decode_length(uint8_t *, uint8_t *);
 uint8_t *cvsup_ignore_bit(uint8_t *, uint8_t *);
 
-static int64_t __int64_const = (int64_t)-1;
-
 uint8_t *
 cvsup_examine(uint8_t *sp, uint8_t *bp)
 {
@@ -87,7 +85,7 @@ cvsup_examine(uint8_t *sp, uint8_t *bp)
 		logmsg_err("This file seems not be CVSup scan file");
 		return (NULL);
 	}
-	if ((ep = memchr(sp, '\n', bp - sp)) == NULL) {
+	if ((ep = memchr(sp, '\n', (size_t)(bp - sp))) == NULL) {
 		logmsg_err("premature EOF");
 		return (NULL);
 	}
@@ -149,7 +147,7 @@ cvsup_search_dir(struct cvsync_attr *attr, uint8_t *sp, uint8_t *bp)
 			return (false);
 		}
 
-		if ((ep = memchr(sp, '\n', bp - sp)) == NULL) {
+		if ((ep = memchr(sp, '\n', (size_t)(bp - sp))) == NULL) {
 			logmsg_err("premature EOF");
 			return (false);
 		}
@@ -168,7 +166,7 @@ cvsup_search_dir(struct cvsync_attr *attr, uint8_t *sp, uint8_t *bp)
 				/* skip in this context. */
 				break;
 			}
-			if (ep - sp <= attr->ca_namelen) {
+			if ((size_t)(ep - sp) <= attr->ca_namelen) {
 				logmsg_err("Not found 'U' for %.*s",
 					   attr->ca_namelen, attr->ca_name);
 				return (false);
@@ -399,21 +397,21 @@ cvsup_decode_attrs(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 {
 	uint32_t attrs = 0;
 	uint8_t *sep;
-	int n;
+	size_t n;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
-		return (-1);
+		return ((uint32_t)-1);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
-		return (-1);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
+		return ((uint32_t)-1);
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
-		return (-1);
+		return ((uint32_t)-1);
 	}
 	if ((n == 0) || (n > sizeof(attrs) * 2)) {
 		logmsg_err("%d: invalid Attrs length", n);
-		return (-1);
+		return ((uint32_t)-1);
 	}
 
 	*new_sp = sp + n;
@@ -421,7 +419,7 @@ cvsup_decode_attrs(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 	while (n-- > 0) {
 		if (!isxdigit((int)(*sp))) {
 			logmsg_err("%c: invalid Attrs specifier", *sp);
-			return (-1);
+			return ((uint32_t)-1);
 		}
 		attrs <<= 4;
 		if (isdigit((int)(*sp)))
@@ -438,29 +436,36 @@ uint8_t
 cvsup_decode_filetype(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 {
 	uint8_t tag, *sep;
-	int type = 0, n, i;
+	size_t n, i;
+	int type = 0, c;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
-		return (-1);
+		return ((uint8_t)-1);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
-		return (-1);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
+		return ((uint8_t)-1);
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
-		return (-1);
+		return ((uint8_t)-1);
 	}
 
 	for (i = 0 ; i < n ; i++) {
 		if (!isdigit((int)(*sp))) {
 			logmsg_err("%c: invalid FileType specifier", *sp);
-			return (-1);
+			return ((uint8_t)-1);
 		}
+		c = (int)(*sp++ - '0');
 		if (INT_MAX / 10 < type) {
 			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
-			return (-1);
+			return ((uint8_t)-1);
 		}
-		type = (type * 10) + *sp++ - '0';
+		type *= 10;
+		if (INT_MAX - type < c) {
+			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
+			return ((uint8_t)-1);
+		}
+		type += c;
 	}
 
 	*new_sp = sp;
@@ -468,7 +473,7 @@ cvsup_decode_filetype(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 	switch (type) {
 	case 0:
 		logmsg_err("%d: unsupported FileType", type);
-		return (-1);
+		return ((uint8_t)-1);
 	case 1:
 		tag = FILETYPE_FILE;
 		break;
@@ -486,7 +491,7 @@ cvsup_decode_filetype(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 		break;
 	default:
 		logmsg_err("%d: unsupported FileType", type);
-		return (-1);
+		return ((uint8_t)-1);
 	}
 
 	return (tag);
@@ -495,23 +500,17 @@ cvsup_decode_filetype(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 int64_t
 cvsup_decode_mtime(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 {
-	int64_t mtime = 0;
+	int64_t mtime = 0, c;
 	uint8_t *sep;
-	int n, i;
+	size_t n, i;
 
-	if (__int64_const == (int64_t)-1) {
-		/* NEVER REMOVE : This kludge is for Cygwin */
-		__int64_const = (int64_t)(UINT64_MAX >> 1);
-		__int64_const /= 10;
-	}
-
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
 		return (-1);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
 		return (-1);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
 		return (-1);
 	}
@@ -521,11 +520,17 @@ cvsup_decode_mtime(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 			logmsg_err("%c: invalid ModTime specifier", *sp);
 			return (-1);
 		}
-		if (__int64_const < mtime) {
+		c = (int64_t)(*sp++ - '0');
+		if (INT64_MAX / 10 < mtime) {
 			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
 			return (-1);
 		}
-		mtime = (mtime * 10) + *sp++ - '0';
+		mtime *= 10;
+		if (INT64_MAX - mtime < c) {
+			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
+			return (-1);
+		}
+		mtime += c;
 	}
 
 	*new_sp = sp;
@@ -536,31 +541,37 @@ cvsup_decode_mtime(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 uint64_t
 cvsup_decode_size(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 {
-	uint64_t size = 0;
+	uint64_t size = 0, c;
 	uint8_t *sep;
-	int n, i;
+	size_t n, i;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
-		return (-1);
+		return ((uint64_t)-1);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
-		return (-1);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
+		return ((uint64_t)-1);
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
-		return (-1);
+		return ((uint64_t)-1);
 	}
 
 	for (i = 0 ; i < n ; i++) {
 		if (!isdigit((int)(*sp))) {
 			logmsg_err("%c: invalid ModTime specifier", *sp);
-			return (-1);
+			return ((uint64_t)-1);
 		}
+		c = (uint64_t)(*sp++ - '0');
 		if (UINT64_MAX / 10 < size) {
 			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
-			return (-1);
+			return ((uint64_t)-1);
 		}
-		size = (size * 10) + *sp++ - '0';
+		size *= 10;
+		if (UINT64_MAX - size < c) {
+			logmsg_err("%.*s: %s", n, sep + 1, strerror(ERANGE));
+			return ((uint64_t)-1);
+		}
+		size += c;
 	}
 
 	*new_sp = sp;
@@ -573,19 +584,19 @@ cvsup_decode_linktarget(uint8_t *sp, uint8_t *ep, uint8_t **new_sp,
 			void *buffer, size_t bufsize)
 {
 	uint8_t *linksp = buffer, *linkbp = linksp + bufsize, *sep;
-	int n;
+	size_t n;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
 		return (0);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
 		return (0);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
 		return (0);
 	}
-	if ((n == 0) || ((size_t)n > bufsize)) {
+	if ((n == 0) || (n > bufsize)) {
 		logmsg_err("%d: invalid LinkTarget length", n);
 		return (0);
 	}
@@ -623,27 +634,27 @@ cvsup_decode_mode(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 {
 	uint16_t mode = 0;
 	uint8_t *sep;
-	int n;
+	size_t n;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
-		return (-1);
+		return ((uint16_t)-1);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
-		return (-1);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
+		return ((uint16_t)-1);
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
-		return (-1);
+		return ((uint16_t)-1);
 	}
 	if ((n == 0) || (n > sizeof(mode) * 2)) {
 		logmsg_err("%d: invalid Mode length", n);
-		return (-1);
+		return ((uint16_t)-1);
 	}
 
 	while (n-- > 0) {
 		if ((*sp < '0') || (*sp > '7')) {
 			logmsg_err("%c: invalid Mode specifier", *sp);
-			return (-1);
+			return ((uint16_t)-1);
 		}
 		mode = (mode << 3) + *sp++ - '0';
 	}
@@ -653,23 +664,30 @@ cvsup_decode_mode(uint8_t *sp, uint8_t *ep, uint8_t **new_sp)
 	return (mode & mode_umask);
 }
 
-int
+size_t
 cvsup_decode_length(uint8_t *sp, uint8_t *ep)
 {
 	uint8_t *sv_sp = sp;
-	int n = 0;
+	size_t n = 0, c;
 
 	while (sp < ep) {
 		if (!isdigit((int)(*sp))) {
 			logmsg_err("%c: invalid length specifier", *sp);
-			return (-1);
+			return ((size_t)-1);
 		}
-		if (INT_MAX / 10 < n) {
+		c = (size_t)(*sp++ - '0');
+		if (SIZE_MAX / 10 < n) {
 			logmsg_err("%.*s: %s", ep - sv_sp, sv_sp,
 				   strerror(ERANGE));
-			return (-1);
+			return ((size_t)-1);
 		}
-		n = (n * 10) + *sp++ - '0';
+		n *= 10;
+		if (SIZE_MAX - n < c) {
+			logmsg_err("%.*s: %s", ep - sv_sp, sv_sp,
+				   strerror(ERANGE));
+			return ((size_t)-1);
+		}
+		n += c;
 	}
 
 	return (n);
@@ -679,15 +697,15 @@ uint8_t *
 cvsup_ignore_bit(uint8_t *sp, uint8_t *ep)
 {
 	uint8_t *sep;
-	int n;
+	size_t n;
 
-	if ((sep = memchr(sp, '#', ep - sp)) == NULL) {
+	if ((sep = memchr(sp, '#', (size_t)(ep - sp))) == NULL) {
 		logmsg_err("no separators");
 		return (NULL);
 	}
-	if ((n = cvsup_decode_length(sp, sep)) == -1)
+	if ((n = cvsup_decode_length(sp, sep)) == (size_t)-1)
 		return (NULL);
-	if (((sp = sep + 1) >= ep) || (ep - sp < n)) {
+	if (((sp = sep + 1) >= ep) || ((size_t)(ep - sp) < n)) {
 		logmsg_err("premature EOF");
 		return (NULL);
 	}
