@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -182,7 +182,7 @@ config_load_uri(const char *uri)
 		bp--;
 	}
 
-	if (bp - sp <= URI_scheme_length) {
+	if ((size_t)(bp - sp) <= URI_scheme_length) {
 		logmsg_err("%s: invalid URI scheme", uri);
 		return (NULL);
 	}
@@ -518,7 +518,7 @@ config_parse_uri(const char *sp, const char *bp)
 		return (NULL);
 	}
 
-	if ((ep = memchr(sp, '/', bp - sp)) == NULL)
+	if ((ep = memchr(sp, '/', (size_t)(bp - sp))) == NULL)
 		ep = bp;
 	if (!config_parse_uri_host(sp, ep, cf)) {
 		config_destroy(cf);
@@ -532,7 +532,7 @@ config_parse_uri(const char *sp, const char *bp)
 		goto done;
 	}
 
-	if ((ep = memchr(sp, '?', bp - sp)) == NULL)
+	if ((ep = memchr(sp, '?', (size_t)(bp - sp))) == NULL)
 		ep = bp;
 	if (!config_parse_uri_collection(sp, ep, cl)) {
 		config_destroy(cf);
@@ -597,7 +597,7 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 			logmsg_err("host: premature EOL");
 			return (false);
 		}
-		if ((ep = memchr(sp, ']', bp - sp)) == NULL) {
+		if ((ep = memchr(sp, ']', (size_t)(bp - sp))) == NULL) {
 			logmsg_err("host: missing ']'");
 			return (false);
 		}
@@ -610,12 +610,12 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 			logmsg_err("host: empty string");
 			return (false);
 		}
-		memcpy(cf->cf_host, sp, len);
+		(void)memcpy(cf->cf_host, sp, len);
 		cf->cf_host[len] = '\0';
 
 		sp = ep + 1;
 	} else {
-		if ((ep = memchr(sp, ':', bp - sp)) == NULL)
+		if ((ep = memchr(sp, ':', (size_t)(bp - sp))) == NULL)
 			ep = bp;
 		if ((len = ep - sp) >= sizeof(cf->cf_host)) {
 			logmsg_err("%.*s: host %.*s: %s", sv_len, sv_sp, len,
@@ -626,7 +626,7 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 			logmsg_err("host: empty string");
 			return (false);
 		}
-		memcpy(cf->cf_host, sp, len);
+		(void)memcpy(cf->cf_host, sp, len);
 		cf->cf_host[len] = '\0';
 
 		sp = ep;
@@ -646,7 +646,7 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 			   strerror(ENAMETOOLONG));
 		return (false);
 	}
-	memcpy(cf->cf_serv, sp, len);
+	(void)memcpy(cf->cf_serv, sp, len);
 	cf->cf_serv[len] = '\0';
 
 	return (true);
@@ -659,7 +659,7 @@ config_parse_uri_collection(const char *sp, const char *bp,
 	const char *ep;
 	size_t len;
 
-	if ((ep = memchr(sp, '/', bp - sp)) == NULL) {
+	if ((ep = memchr(sp, '/', (size_t)(bp - sp))) == NULL) {
 		logmsg_err("name: premature EOL");
 		return (false);
 	}
@@ -671,14 +671,14 @@ config_parse_uri_collection(const char *sp, const char *bp,
 		logmsg_err("name: empty string");
 		return (false);
 	}
-	memcpy(cl->cl_name, sp, len);
+	(void)memcpy(cl->cl_name, sp, len);
 	cl->cl_name[len] = '\0';
 
 	if ((sp = ep + 1) >= bp) {
 		logmsg_err("release: premature EOL");
 		return (false);
 	}
-	if ((ep = memchr(sp, '/', bp - sp)) == NULL) {
+	if ((ep = memchr(sp, '/', (size_t)(bp - sp))) == NULL) {
 		logmsg_err("release: premature EOL");
 		return (false);
 	}
@@ -691,7 +691,7 @@ config_parse_uri_collection(const char *sp, const char *bp,
 		logmsg_err("release: empty string");
 		return (false);
 	}
-	memcpy(cl->cl_release, sp, len);
+	(void)memcpy(cl->cl_release, sp, len);
 	cl->cl_release[len] = '\0';
 
 	switch (cvsync_release_pton(cl->cl_release)) {
@@ -718,9 +718,9 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 	size_t len;
 
 	while (sp < bp) {
-		if ((ep = memchr(sp, '&', bp - sp)) == NULL)
+		if ((ep = memchr(sp, '&', (size_t)(bp - sp))) == NULL)
 			ep = bp;
-		if ((sep = memchr(sp, '=', ep - sp)) == NULL)
+		if ((sep = memchr(sp, '=', (size_t)(ep - sp))) == NULL)
 			len = ep - sp;
 		else
 			len = sep - sp;
@@ -769,7 +769,7 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 					   cl->cl_release, key->name);
 				return (false);
 			}
-			memcpy(cl->cl_prefix, sp, cl->cl_prefixlen);
+			(void)memcpy(cl->cl_prefix, sp, cl->cl_prefixlen);
 			cl->cl_prefix[cl->cl_prefixlen] = '\0';
 
 			break;
@@ -799,7 +799,7 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 					   cl->cl_release, key->name);
 				return (false);
 			}
-			memcpy(cl->cl_scan_name, sp, len);
+			(void)memcpy(cl->cl_scan_name, sp, len);
 			cl->cl_scan_name[len] = '\0';
 
 			break;
@@ -824,7 +824,7 @@ config_init_config(void)
 		logmsg_err("%s", strerror(errno));
 		return (NULL);
 	}
-	memset(cf, 0, sizeof(*cf));
+	(void)memset(cf, 0, sizeof(*cf));
 
 	cf->cf_family = AF_UNSPEC;
 	cf->cf_compress = CVSYNC_COMPRESS_UNSPEC;
@@ -842,7 +842,7 @@ config_init_collection(void)
 		logmsg_err("%s", strerror(errno));
 		return (NULL);
 	}
-	memset(cl, 0, sizeof(*cl));
+	(void)memset(cl, 0, sizeof(*cl));
 
 	cl->cl_errormode = CVSYNC_ERRORMODE_UNSPEC;
 	cl->cl_umask = CVSYNC_UMASK_UNSPEC;
