@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -112,14 +112,14 @@ access_init(size_t sz)
 		logmsg_err("ACL: %s", strerror(errno));
 		return (false);
 	}
-	memset(acl, 0, sz * sizeof(*acl));
+	(void)memset(acl, 0, sz * sizeof(*acl));
 
 	if ((acl_high = list_init()) == NULL) {
 		free(acl);
 		return (false);
 	}
 
-	gettimeofday(&tv, NULL);
+	(void)gettimeofday(&tv, NULL);
 
 #if !defined(NO_INITSTATE)
 	initstate((unsigned long)tv.tv_usec, acl_random_state,
@@ -391,31 +391,31 @@ access_open(const char *fname)
 	}
 	if (fstat(fd, &st) == -1) {
 		logmsg_err("ACL: %s: %s", fname, strerror(errno));
-		close(fd);
+		(void)close(fd);
 		return;
 	}
 
 	if (!force_load && (st.st_mtime == acl_mtime)) {
-		close(fd);
+		(void)close(fd);
 		return;
 	}
 	acl_mtime = st.st_mtime;
 
 	if (st.st_size == 0) {
-		close(fd);
+		(void)close(fd);
 		aca = NULL;
 		goto done;
 	}
 
 	if ((fp = fdopen(fd, "r")) == NULL) {
 		logmsg_err("ACL: %s: %s", fname, strerror(errno));
-		close(fd);
+		(void)close(fd);
 		return;
 	}
 
 	if ((aca = access_parse(fp)) == NULL) {
 		logmsg_err("ACL: %s: failed to load", fname);
-		fclose(fp);
+		(void)fclose(fp);
 		return;
 	}
 
@@ -526,8 +526,8 @@ access_parse(FILE *fp)
 			}
 
 			if (aca->aca_patterns != NULL) {
-				memcpy(newptr, aca->aca_patterns,
-				       old * sizeof(*newptr));
+				(void)memcpy(newptr, aca->aca_patterns,
+					     old * sizeof(*newptr));
 				free(aca->aca_patterns);
 			}
 			aca->aca_patterns = newptr;
@@ -594,7 +594,7 @@ access_parse_allow(struct token *tk, struct aclent *aclp)
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
 	size_t n;
 
-	if ((sep = memchr(sp, ',', bp - sp)) != NULL) {
+	if ((sep = memchr(sp, ',', (size_t)(bp - sp))) != NULL) {
 		if (sep + 1 >= bp)
 			return (false);
 		if (!access_parse_number(sep + 1, bp, &aclp->acl_max))
@@ -602,7 +602,7 @@ access_parse_allow(struct token *tk, struct aclent *aclp)
 		bp = sep;
 	}
 
-	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
+	if ((sep = memchr(sp, '/', (size_t)(bp - sp))) != NULL) {
 		if (sep + 1 >= bp)
 			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
@@ -622,7 +622,7 @@ access_parse_always(struct token *tk, struct aclent *aclp)
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
 	size_t n;
 
-	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
+	if ((sep = memchr(sp, '/', (size_t)(bp - sp))) != NULL) {
 		if (sep + 1 >= bp)
 			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
@@ -642,7 +642,7 @@ access_parse_deny(struct token *tk, struct aclent *aclp)
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
 	size_t n;
 
-	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
+	if ((sep = memchr(sp, '/', (size_t)(bp - sp))) != NULL) {
 		if (sep + 1 >= bp)
 			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
@@ -664,7 +664,7 @@ access_parse_address(char *sp, const char *bp, size_t n, struct aclent *aclp)
 
 	if ((addrlen = bp - sp) >= sizeof(addr))
 		return (false);
-	memcpy(addr, sp, addrlen);
+	(void)memcpy(addr, sp, addrlen);
 	addr[addrlen] = '\0';
 
 	if (inet_pton(AF_INET, addr, binaddr) == 1) {
@@ -685,7 +685,7 @@ bool
 access_parse_hostname(char *sp, const char *bp, struct aclent *aclp)
 {
 	if (isdigit((int)(sp[bp - sp - 1])) ||
-	    (memchr(sp, ':', bp - sp) != NULL)) {
+	    (memchr(sp, ':', (size_t)(bp - sp)) != NULL)) {
 		return (false);
 	}
 
@@ -695,7 +695,7 @@ access_parse_hostname(char *sp, const char *bp, struct aclent *aclp)
 		logmsg_err("ACL: %s", strerror(errno));
 		return (false);
 	}
-	memcpy(aclp->acl_addr, sp, aclp->acl_addrlen);
+	(void)memcpy(aclp->acl_addr, sp, aclp->acl_addrlen);
 	((char *)aclp->acl_addr)[aclp->acl_addrlen] = '\0';
 	aclp->acl_mask = NULL;
 
@@ -713,7 +713,7 @@ access_parse_number(char *sp, const char *bp, size_t *n)
 		logmsg_err("ACL: %.*s: restricted to 1000", len, sp);
 		return (false);
 	}
-	memcpy(s, sp, len);
+	(void)memcpy(s, sp, len);
 	s[len] = '\0';
 
 	errno = 0;
@@ -772,7 +772,7 @@ access_match_ipv4addr(struct aclent *aclp, const void *addr)
 {
 	uint32_t v4pat = *(uint32_t *)aclp->acl_addr;
 	uint32_t v4mask = *(uint32_t *)aclp->acl_mask;
-	uint32_t v4addr = *(uint32_t *)addr;
+	uint32_t v4addr = *(const uint32_t *)addr;
 
 	if (v4pat != (v4addr & v4mask))
 		return (false);
@@ -798,7 +798,7 @@ access_match_ipv6addr(struct aclent *aclp, const void *addr)
 bool
 access_set_ipv4addr(struct aclent *aclp, const void *addr, size_t netmask)
 {
-	uint32_t v4addr = *(uint32_t *)addr, v4mask;
+	uint32_t v4addr = *(const uint32_t *)addr, v4mask;
 	size_t addrbits, n;
 
 	aclp->acl_addrlen = sizeof(uint32_t);
@@ -851,7 +851,8 @@ access_set_ipv6addr(struct aclent *aclp, const void *addr, size_t prefixlen)
 	if ((prefixlen % 8) != 0) {
 		if ((i = 8 - (prefixlen - n * 8)) > 0) {
 			v6mask[n] = 0xff >> i;
-			v6mask[n++] <<= i;
+			v6mask[n] = v6mask[n] << i;
+			n++;
 		}
 	}
 	while (n < aclp->acl_addrlen)
@@ -869,7 +870,7 @@ access_set_ipv6addr(struct aclent *aclp, const void *addr, size_t prefixlen)
 
 	for (i = 0 ; i < aclp->acl_addrlen ; i++)
 		((uint8_t *)aclp->acl_addr)[i] = v6addr[i] & v6mask[i];
-	memcpy(aclp->acl_mask, v6mask, aclp->acl_addrlen);
+	(void)memcpy(aclp->acl_mask, v6mask, aclp->acl_addrlen);
 
 	return (true);
 }
