@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2005 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,7 @@
 #include <unistd.h>
 
 #include "compat_stdbool.h"
+#include "compat_stdint.h"
 #include "compat_stdio.h"
 #include "compat_stdlib.h"
 #include "compat_inttypes.h"
@@ -421,6 +422,7 @@ main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 
 	exit(status);
+	/* NOTREACHED */
 }
 
 void *
